#
# spec file for package hydrogen
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soversion 0
%define soage 0
%define sorevision 0
# WARNING: ATM librubberband2 support is experimental currently it is recommended that you disable
# this config option to ensure backwards compatibility with songs created under 0.9.5 which use
# rubberband. Use the rubberband -cli package instead.
%define librubberband 0

Name:           hydrogen
BuildRequires:  alsa-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa
BuildRequires:  ladspa-devel
BuildRequires:  lash-devel
BuildRequires:  libarchive-devel
BuildRequires:  libjack-devel
BuildRequires:  liblrdf-devel
BuildRequires:  libqt4-devel
BuildRequires:  libraptor-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pkg-config
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  util-linux
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt3Support)
BuildRequires:  pkgconfig(QtCLucene)
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtDBus)
BuildRequires:  pkgconfig(QtDeclarative)
BuildRequires:  pkgconfig(QtDesigner)
BuildRequires:  pkgconfig(QtDesignerComponents)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtHelp)
BuildRequires:  pkgconfig(QtMultimedia)
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(QtOpenGL)
BuildRequires:  pkgconfig(QtScript)
BuildRequires:  pkgconfig(QtScriptTools)
BuildRequires:  pkgconfig(QtSql)
BuildRequires:  pkgconfig(QtSvg)
BuildRequires:  pkgconfig(QtTest)
BuildRequires:  pkgconfig(QtUiTools)
BuildRequires:  pkgconfig(QtXml)
BuildRequires:  pkgconfig(QtXmlPatterns)

#%%if 0%%{?suse_version} <= 1140
#BuildRequires:  libqt4-devel-doc-data
#%%endif
#pkgconfig(ladspa-1.13)
%if 0%{?librubberband} == 1
BuildRequires:  librubberband-devel
%else
Requires:       rubberband-cli
BuildRequires:  rubberband-cli
%endif
Summary:        A Real-Time Drum Machine and Sequencer
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Midi
# NOTE: Don't forget to update the libsuffix macro.
Version:        0.9.6
Release:        17.37
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://www.hydrogen-music.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        hydrogen.1
Source2:        h2cli.1
Source3:        COPYING
# Fixup the desktop file.
Patch0:         hydrogen-0.9.6-desktop.patch
# Remove current date and time from sources.
Patch1:         hydrogen-no-current-time.patch
# libhydrogencore has no soname and installs in _libexecdir
Patch2:         hydrogen-0.9.6-lib64.patch
# PATCH-FIX-UPSTREAM hydrogen-gcc47.patch boris@steki.net -- Fix build with gcc 4.7.
Patch3:         hydrogen-gcc47.patch

%description
Hydrogen is an advanced drum machine for GNU/Linux.
It's main goal is to bring professional yet simple and intuitive
pattern-based drum programming. sequencer MIDI input.
Very user-friendly, modular, fast and intuitive graphical
interface based on QT4.
Sample-based stereo audio engine, with import of sound samples
in .wav, .au and .aiff formats.
Pattern-based sequencer, with unlimited number of patterns and
ability to chain patterns into a song.
Up to 64 ticks per pattern with individual level per event and
variable pattern length.
32 instrument tracks with volume, mute, solo, pan capabilities.
Multi layer support for instruments (up to 16 samples for each
instrument).
Ability to import/export song files.
Unique human velocity, human time, pitch and swing functions.
Multiple patterns playing at once.
JACK, ALSA, PortAudio and OSS audio drivers.
ALSA MIDI input with assignable midi-in channel (1..16, ALL).
Import/export of drumkits.
Export song to wav file.
Export song to midi file.

%package -n libhydrogen-core%{soversion}
Summary:        Library essential for hydrogen
Group:          System/Libraries

%description -n libhydrogen-core%{soversion}
This is the core of hydrogen's operation.

%package -n libhydrogen-core-devel
Summary:        Development files and headers for libhydrogen-core
Group:          Development/Libraries/C and C++
Requires:       libhydrogen-core%{soversion} = %{version}-%{release}

%description -n libhydrogen-core-devel
These are the headers needed to develop apps that
link with libhydrogen-core.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3

# copy licence with correct fsf address
install -m 0644 %{S:3} ./

%build

mkdir -p Build && pushd Build
cmake -L ../ -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
	-DCMAKE_LIBRARY_ARCHITECTURE:STRING=%{_arch} \
	-DCMAKE_CXX_FLAGS:STRING="%{optflags} -ggdb" \
	-DCMAKE_C_FLAGS:STRING="%{optflags} -ggdb" \
	-DCMAKE_BUILD_TYPE:STRING=Release \
	-DCMAKE_VERBOSE_MAKEFILE:BOOL=on \
	-DWANT_SHARED:BOOL=on \
	-DWANT_LIBARCHIVE:BOOL=on \
	-DWANT_LRDF:BOOL=off \
	-DWANT_LASH:BOOL=on \
	-DLADSPA_INCLUDE_DIR:PATH=%{_includedir} \
	-DLADSPA_LIBRARIES:PATH=%{_libdir}/ladspa \
	-DCMAKE_CURRENT_LIBRARY_DIR:PATH="%{_lib}" \
	-Dcoreversion:STRING=%{soversion} \
	-Dsoage:STRING=%{soage} \
	-Dsorevision:STRING=%{sorevision} \

# For some reason cmake won't produce a correct soname with only the version so this is a hack to fix it.
pushd src/core/CMakeFiles/hydrogen-core.dir && \
cat link.txt|sed 's/-soname,libhydrogen-core.so.0.0.0/-soname,libhydrogen-core.so.0/'>\
link.txt~;mv link.txt~ link.txt

cat relink.txt|sed 's/-soname,libhydrogen-core.so.0.0.0/-soname,libhydrogen-core.so.0/'>\
relink.txt~;mv relink.txt~ relink.txt

popd

make %{?_smp_mflags}

# LD_LIBRARY_PATH=%%{_libdir}/mpi/gcc/openmpi/%%{_lib}
# LD_RUN_PATH=%%{_libdir}

popd

%install

#export QTDIR=%%{_libdir}/qt4/
pushd Build
%makeinstall VERBOSE_MAKEFILE=1
# libhydrogen-core's internal SONAME = libhydrogen-core.so.0 so we provide a link.
cd %{buildroot}%{_libdir} && ln -s libhydrogen-core.so.0.0.0 libhydrogen-core.so.0
popd

# Install the man pages created by help2man
mkdir -p %{buildroot}%{_mandir}/man1
install -pm 0644 %{S:1} %{S:2} %{buildroot}%{_mandir}/man1/

# temporary link i18n files from usr/share/hydrogen/data/i18n to _datadir/locale for find_lang to find.
ln -s %{_datadir}/hydrogen/data/i18n %{buildroot}%{_datadir}/locale
%find_lang %{name} %{name}.lang --without-kde --with-qt --all-name --without-mo
rm -rf %{buildroot}%{_datadir}/locale
cat %{name}.lang

# Set executable bit on scripts in buildroot/_datadir/name/data/i18n
for i in $(find %{buildroot}%{_datadir}/hydrogen/data/i18n -type f -perm 0644 -print0|xargs -0r grep -l '#!'); \
do chmod 0755 ${i}; done

%fdupes -s %{buildroot}%{_datadir}

# Make icon avalable for desktop file
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/ \
&& pushd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ln -s ../../../../%{name}/data/img/gray/h2-icon.svg h2-icon.svg
#usr/share/hydrogen/data/img/gray/h2-icon.svg
popd && %suse_update_desktop_file -i %{name} AudioVideo Sequencer

%post
update-desktop-database > /dev/null 2>&1 || :

%postun
update-desktop-database > /dev/null 2>&1 || :

%files -f %{name}.lang
%defattr(-, root, root)
%{_bindir}/*
%doc AUTHORS COPYING ChangeLog README.txt
%dir %{_datadir}/%{name}/*
%dir %{_datadir}/%{name}
%{_mandir}/man1/hydrogen.1.gz
%{_mandir}/man1/h2cli.1.gz
%{_datadir}/%{name}/data/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/h2-icon.svg

%post -n libhydrogen-core%{soversion} -p /sbin/ldconfig

%postun -n libhydrogen-core%{soversion} -p /sbin/ldconfig

%files -n libhydrogen-core%{soversion}
%defattr(-, root, root)
%{_libdir}/libhydrogen-core.so.%{soversion}*

%files -n libhydrogen-core-devel
%defattr(-, root, root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*
%{_libdir}/libhydrogen-core.so

%changelog
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Fri Sep  5 2014 wbauer@tmo.at
- Update to final version 0.9.6, adapt patches
- Changed hydrogen-0.9.6-desktop.patch to not add quotes to the
  german Name and GenericName entries in the .desktop file, this
  doesn't really make sense and looks bad in the application menu
- Updated h2cli.1 and hydrogen.1 man pages
- Upstream changes (compared to 0.9.5):
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * jack-midi support
  * several bug fixes
  * tabbed interface
  * several small changes to the GUI
  * improve ExportSong add use of TimeLineBPM,
    RubberbandBatch processor and different types of resample interpolation
* Sat Nov 23 2013 wbauer@tmo.at
- Update to version 0.9.6-beta3, adapt patches
- Upstream changes:
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * jack-midi support
  * several bug fixes
  * tabbed interface
  * several small changes to the GUI
  * improve ExportSong add use of TimeLineBPM,
    RubberbandBatch processor and different types of resample interpolation
* Sun Jun  2 2013 andreas.stieger@gmx.de
- remove build requirements subversion and rsync
* Sat Mar 17 2012 boris@steki.net
- Add hydrogen-gcc47.patch: Fix build with gcc 4.7.
* Tue Oct 25 2011 coolo@suse.com
- fix another link into %%buildroot
* Fri Oct 14 2011 davejplater@gmail.com
- Changed build to release due to the default debug build being
  sluggish.
* Tue Oct 11 2011 davejplater@gmail.com
- Gave libhydrogen-core.so a SONAME and fixed the <= 11.4 build
  which needed Qt webkit to have QtXmlPatterns with
  BuildRequires: pkgconfig(QtXmlPatterns)
* Wed Oct  5 2011 davejplater@gmail.com
- Update to version 0.9.6, all patches obsolete, remade
  hydrogen-no-current-time.patch & hydrogen-0.9.6-desktopfile.patch
- Build system now uses cmake, rewrote the Build section and added
  man page for h2cli. Created devel and libhydrogen-core-0_9_6-0
  sub packages.
- Upstream changes :
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * some bug fixes
* Sun Aug 14 2011 ro@suse.de
- make it build even if python reports platform as linux3
* Fri Mar 18 2011 davejplater@gmail.com
- Update to Version 0.9.5 added portaudio.patch from upstream.
- Made hydrogen-no-current-time.patch use __TIMESTAMP__ instead of
  __DATE__
- No more kde3 dependency since version 0.9.4, now uses Qt4.
- Added man page created with hepl2man.
- Added hydrogen-0.9.5-desktopfile.patch which replaces
  linux/hydrogen.desktop file which is installed with the one in
  the top source directory.
- Upstream changes :
  * load playlists at startup
  * midi-learn works now with shift-click on some gui elements
  * multi-track export and LADI support
  * maximum number of bars is now configurable
  * added czech translation
  * fixed serveral export song failures
  * added ogg, flac, aiff export support
  * added some new commandline parameter for no_gui version
  * added rubberband-cli support
  * several improvements on sample editor
  * added support for app bundles on OSX
  * non destructive sample editor
  * piano roll editor and instrument midi out
  * destructive midi recording and added czech translation
  * support for midi "note off" messages & virtual patterns
  * time line to change song tempo and add tags
  * director and at least several small changes
  * Xml handling is now done by QtXml instead of TinyXML
  * improved support for non-ascii filenames / strings
  * remove direct dependencies to libflac
- For earlier 0.9.4 changes see ChangeLog
* Fri Mar 26 2010 coolo@novell.com
- disable parallel make to avoid the random failures we see
* Mon May 18 2009 tiwai@suse.de
- fix build with gcc 4.4; add missing stdio.h inclusions
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3
* Mon Jun  4 2007 dmueller@suse.de
- remove FLAC 1.1.4 patch for < 10.3
* Mon May  7 2007 stbinner@suse.de
- fix build on < 10.3
* Thu May  3 2007 wstephenson@suse.de
- fix buildrequires: libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- fix buildrequires: raptor-devel -> libraptor1-devel
* Mon Apr 16 2007 tiwai@suse.de
- fix build with FLAC 1.1.4.
* Thu Jan 18 2007 tiwai@suse.de
- use RPM_OPT_FLAGS for plugins.
* Mon Jul 31 2006 tiwai@suse.de
- updated to version 0.9.3:
  * mostly bugfixes, including memory leak (#194576)
  * new plugins
* Thu Jun 15 2006 dmueller@suse.de
- build parallel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 18 2005 tiwai@suse.de
- fixed for gcc 4.1.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 0.9.2.
* Wed May 11 2005 schwab@suse.de
- Fix library order.
- Fix broken cast.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.9.1.
* Thu Dec 16 2004 coolo@suse.de
- tried to fix Makefiles, but disabled unsermake in the middle
* Wed Aug 25 2004 mana@suse.de
- update to 0.8.2 (non-beta)
* Mon Aug 16 2004 ro@suse.de
- run update_admin
* Tue Mar  2 2004 tiwai@suse.de
- updated to version 0.8.2beta1.
* Fri Feb 20 2004 tiwai@suse.de
- fixed the installation of desktop file.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 0.8.1.
  libhydrogen is merged again.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Sep 19 2003 tiwai@suse.de
- fixed the desktop icon path.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icons.
* Fri Aug 29 2003 tiwai@suse.de
- added %%run_ldconfig.
- fixed categories.
* Thu Aug 28 2003 tiwai@suse.de
- fixed the change of types in the recent JACK.
* Thu Aug 14 2003 tiwai@suse.de
- added desktop file.
* Mon Jul  7 2003 tiwai@suse.de
- updated to version 0.8.0.
* Tue Apr  1 2003 tiwai@suse.de
- initial version: 0.7.6.
